# jax-decision-making

[![PyPI - Version](https://img.shields.io/pypi/v/jax-decision-making.svg)](https://pypi.org/project/jax-decision-making)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/jax-decision-making.svg)](https://pypi.org/project/jax-decision-making)

`jax-decision-making` offers a collection of algorithms for sequential decision-making problems, including reinforcement learning, planning, and bandit algorithms. The implementations are built upon the JAX library, enabling automatic differentiation, vectorisation, and just-in-time (JIT) compilation to native code for high performance on CPUs, GPUs, and TPUs. This allows for efficient research, development, and deployment of decision-making agents.

-----

## Table of Contents

- [jax-decision-making](#jax-decision-making)
  - [Table of Contents](#table-of-contents)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install jax-decision-making
```

## License

`jax-decision-making` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
